local AddonName, GuildInspector = ...
local AddonTitle = GetAddOnMetadata(AddonName, "Title") or AddonName;
local AddonVersion = GetAddOnMetadata(AddonName, "Version") or "?";

local L = GuildInspector.L

-- ToDo:
-- fix old column content visible
-- option dialog:
-- 		filter columns
-- 		key bindings button
-- context menus

local GUILDINSPECTOR_COLUMNSETUPS = {
	roster = {1, 2, 3, 4, 5, 6, 7, 8},
	log = {9, 10},
};
local GUILDINSPECTOR_COLUMNTYPES = {
	{width =  24, text = LEVEL_ABBR, sort="level", alignment="CENTER"},
	{width =  16, text = CLASS_ABBR, sort="class", alignment="LEFT"},
	{width = 101, text = NAME, sort="name", alignment="LEFT"},
	{width = 136, text = ZONE, sort="zone", alignment="LEFT"},
	{width =  76, text = RANK, sort="rank", alignment="LEFT"},
	{width = 128, text = LABEL_NOTE, sort="note", alignment="LEFT"},
	{width = 128, text = OFFICER_NOTE_COLON, sort="officernote", alignment="LEFT"},
	{width =  76, text = LASTONLINE, sort="online", alignment="LEFT"},
	{width = 400, text = L.EVENT, sort="", alignment="LEFT"},
	{width =  76, text = L.TIME, sort="", alignment="LEFT"},
};

local MOBILE_BUSY_ICON = "|TInterface\\ChatFrame\\UI-ChatIcon-ArmoryChat-BusyMobile:14:14:0:0:16:16:0:16:0:16|t";
local MOBILE_AWAY_ICON = "|TInterface\\ChatFrame\\UI-ChatIcon-ArmoryChat-AwayMobile:14:14:0:0:16:16:0:16:0:16|t";

BINDING_HEADER_GUILDINSPECTOR = "Guild Inspector";
BINDING_NAME_GUILDINSPECTOR_TOGGLESWITCH = "toggle window / switch tab";

local function IsConnectedRealm(name)
	local _, realm = strsplit("-", name);
	if realm == nil then return true; end;

	local connectedRealms = GetAutoCompleteRealms();
	for _, r in ipairs(connectedRealms) do
		if (r == realm) then return true; end
	end
	return false;
end

local function SetDefaultBinding(key, action)
	local currentKeys = GetBindingKey(action);
	local currentAction = GetBindingAction(key);
	if ((currentKeys == nil) and (currentAction == "")) then
		SetBinding(key, action);
		SaveBindings(GetCurrentBindingSet());
	end
end

local function GetFullName(name)
	if (name and (Ambiguate(name, "short") == name)) then
		_, realm = UnitFullName("player");
		name = name .. "-" .. realm;
	end
	return name;
end

--------------------------------------------------------------------------------
-- GuildInspectorFrame Events
--------------------------------------------------------------------------------

function GuildInspectorFrame_OnLoad(self)
	print(AddonTitle .. " v" .. AddonVersion);

	GuildInspectorFrameInset:SetPoint("TOPLEFT", 4, -90);
	GuildInspectorFrameInset:SetPoint("BOTTOMRIGHT", -7, 26);
	GuildInspectorContainer.update = GuildInspectorFrame_Update;
	HybridScrollFrame_CreateButtons(GuildInspectorContainer, "GuildInspectorButtonTemplate", 0, 0, "TOPLEFT", "TOPLEFT", 0, -2, "TOP", "BOTTOM");
	PanelTemplates_SetNumTabs(self, 2);
	PanelTemplates_SetTab(self, GuildInspectorFrameTab1:GetID());
	GuildInspectorFrame_SetView();

	local loaded, finished = IsAddOnLoaded("Blizzard_GuildUI");
	if (loaded) then
		GuildRosterShowOfflineButton:HookScript("OnClick", GuildInspectorShowOfflineButton_OnClickHook);
	end

	self:RegisterEvent("ADDON_LOADED");
	self:RegisterEvent("UPDATE_BINDINGS");
	self:RegisterEvent("PLAYER_GUILD_UPDATE");
	self:RegisterEvent("GUILD_ROSTER_UPDATE");
	self:RegisterEvent("GUILD_EVENT_LOG_UPDATE");

	self:SetAttribute("UIPanelLayout-defined", true);
	self:SetAttribute("UIPanelLayout-enabled", true);
	self:SetAttribute("UIPanelLayout-area", "left");
	self:SetAttribute("UIPanelLayout-pushable", 1);
	self:SetAttribute("UIPanelLayout-whileDead", true);

	tinsert(UISpecialFrames, self:GetName());

	local optionsPanel = CreateFrame("Frame", "GuildInspectorOptionsPanel");
	optionsPanel.name = "Guild Inspector";
	optionsPanel.default = function() GuildInspector_Settings = {} end
	optionsPanel.okay = function()
		GuildInspector_Settings.toggleFunctionality = optionsPanel.toggleFunctionality:GetChecked();
	end
	optionsPanel.refresh = function()
		optionsPanel.toggleFunctionality:SetChecked(GuildInspector_Settings.toggleFunctionality);
	end
	InterfaceOptions_AddCategory(optionsPanel);

	optionsPanel.title = optionsPanel:CreateFontString();
	optionsPanel.title:SetPoint("TOPLEFT", 16, -16);
	optionsPanel.title:SetFontObject("GameFontNormalLarge");
	optionsPanel.title:SetText(AddonTitle .. " v" .. AddonVersion);

	optionsPanel.subText = optionsPanel:CreateFontString();
	optionsPanel.subText:SetFontObject("GameFontHighlightSmall");
	optionsPanel.subText:SetText(L.CONFIG_SUBTEXT);
	optionsPanel.subText:SetPoint("TOPLEFT", optionsPanel.title, "BOTTOMLEFT", 0, -8);

	optionsPanel.toggleFunctionality = CreateFrame("CheckButton", nil, optionsPanel, "UICheckButtonTemplate");
	optionsPanel.toggleFunctionality:SetPoint("TOPLEFT", optionsPanel.subText, 'BOTTOMLEFT', -2, -8);

	optionsPanel.toggleFunctionality.text = optionsPanel.toggleFunctionality:CreateFontString();
	optionsPanel.toggleFunctionality.text:SetFontObject("GameFontHighlightLeft");
	optionsPanel.toggleFunctionality.text:SetText(L.CONFIG_TOGGLEFUNCTIONALITY);
	optionsPanel.toggleFunctionality.text:SetPoint("LEFT", optionsPanel.toggleFunctionality, "RIGHT", 2, 1);
end

function GuildInspectorFrame_OnEvent(self, event, ...)
	if (event == "ADDON_LOADED") then
		local arg1 = select(1, ...);
		if (arg1 == AddonName) then
			GuildInspectorFrame_UpdateGuild();
			if (GuildInspector_Roster == nil) then GuildInspector_Roster = {} end
			if (GuildInspector_Missing == nil) then GuildInspector_Missing = {} end
			if (GuildInspector_Settings == nil) then GuildInspector_Settings = {} end
		elseif (arg1 == "Blizzard_GuildUI") then
			GuildRosterShowOfflineButton:HookScript("OnClick", GuildInspectorShowOfflineButton_OnClickHook);
		end
	elseif (event == "UPDATE_BINDINGS") then
		SetDefaultBinding("CTRL-J", "GUILDINSPECTOR_TOGGLESWITCH");
	elseif (event == "PLAYER_GUILD_UPDATE") then
		GuildInspectorFrame_UpdateGuild();
	elseif (event == "GUILD_ROSTER_UPDATE") then
		GuildInspectorFrame_Update();
	elseif (event == "GUILD_EVENT_LOG_UPDATE") then
		GuildInspectorFrame_Update();
	else
		print("[OnEvent] " .. event);
	end
end

function GuildInspectorFrame_OnShow(self)
	PlaySound(SOUNDKIT.IG_CHARACTER_INFO_OPEN);
	if (IsInGuild()) then
		GuildRoster();
		QueryGuildEventLog();
	end
	GuildInspectorFrame_Update();
end

function GuildInspectorFrame_OnHide(self)
	PlaySound(SOUNDKIT.IG_CHARACTER_INFO_CLOSE);
end

--------------------------------------------------------------------------------
-- GuildInspectorTitleButton Events
--------------------------------------------------------------------------------

function GuildInspectorTitleButton_OnLoad(self)
	self:RegisterForDrag("LeftButton");
end

function GuildInspectorTitleButton_OnClick(self, button)
	PlaySound(SOUNDKIT.U_CHAT_SCROLL_BUTTON);
end

function GuildInspectorTitleButton_OnDragStart(self, button)
	GuildInspectorFrame:StartMoving();
end

function GuildInspectorTitleButton_OnDragStop(self)
	GuildInspectorFrame:StopMovingOrSizing();
end

--------------------------------------------------------------------------------
-- GuildInspectorColumnButton Events
--------------------------------------------------------------------------------

function GuildInspectorColumnButton_OnClick(self, button, down)
	local tabIndex = GuildInspectorFrame.selectedTab;
	if (tabIndex == 1) then
		SortGuildRoster(self.sort);
	elseif (tabIndex == 2) then
		-- ToDo?
	end
	PlaySound(SOUNDKIT.IG_MAINMENU_OPTION_CHECKBOX_ON);
end

--------------------------------------------------------------------------------
-- GuildInspectorButton Events
--------------------------------------------------------------------------------

function GuildInspectorButton_OnEnter(self, motion)
	if (self.tt) then
		local fullName = GetFullName(self.tt);
		local guildName, _, _ = GetGuildInfo("player");

		-- find missing chars
		local current = GuildInspector_Roster[guildName];
		local missing = GuildInspector_Missing[guildName];
		local char = current and current[fullName];
		if (char == nil) then char = missing and missing[fullName] end

		local classTable = {};
		FillLocalizedClassList(classTable, false);
--		classDisplayName, classTag, classID = GetClassInfo(index)

		GameTooltip:SetOwner(self, "ANCHOR_CURSOR");
		if (char) then
			GameTooltip:SetText(self.tt .. GRAY_FONT_COLOR_CODE .. " (" .. char.rank .. ")|r");
			GameTooltip:AddLine("|c" .. RAID_CLASS_COLORS[char.class].colorStr .. classTable[char.class] .. "|r (" .. LEVEL .. " " .. char.level .. ")", 0.5, 0.5, 0.5, true);
			GameTooltip:AddDoubleLine(NOTE_COLON, char.note, 0.5, 0.5, 0.5, 1, 1, 1);
			GameTooltip:AddDoubleLine(L.ONOTE .. ":", char.oNote, 0.5, 0.5, 0.5, 1, 1, 1);
		else
			GameTooltip:SetText(self.tt);
			GameTooltip:AddLine(UNKNOWN, 0.5, 0.5, 0.5, true);
		end

		GameTooltip:Show();
	else
		GameTooltip:Hide();
	end
end

function GuildInspectorButton_OnLeave(self, motion)
	GameTooltip:Hide();
end

--------------------------------------------------------------------------------
-- GuildInspectorShowOfflineButton Events
--------------------------------------------------------------------------------

function GuildInspectorShowOfflineButton_OnClick(self, button, down)
	if (GuildRosterShowOfflineButton) then
		GuildRosterShowOfflineButton:Click(button);
	else
		if ( self:GetChecked() ) then
			PlaySound(SOUNDKIT.IG_MAINMENU_OPTION_CHECKBOX_OFF);
		else
			PlaySound(SOUNDKIT.IG_MAINMENU_OPTION_CHECKBOX_ON);
		end
		SetGuildRosterShowOffline(self:GetChecked());
		GuildInspectorFrame_Update();
	end
end

function GuildInspectorShowOfflineButton_OnClickHook(self, button, down)
	GuildInspectorShowOfflineButton:SetChecked(GetGuildRosterShowOffline());
	GuildInspectorFrame_Update();
end

--------------------------------------------------------------------------------
-- GuildInspectorTabButton Events
--------------------------------------------------------------------------------

function GuildInspectorTabButton_OnClick(self, button, down)
	PlaySound(SOUNDKIT.IG_CHARACTER_INFO_TAB);
	PanelTemplates_SetTab(self:GetParent(), self:GetID());
	GuildInspectorFrame_SetView();
	GuildInspectorFrame_Update();
end

function GuildInspectorTabButton_OnShow(self)
	PanelTemplates_TabResize(self, 0);
end

--------------------------------------------------------------------------------
-- GuildInspector
--------------------------------------------------------------------------------

function GuildInspector:UpdatePlayerGuild()
	-- ToDo?
end

function GuildInspector:UpdateGuildRoster()
	-- ToDo?
end

function GuildInspector:UpdateGuildEventLog()
	-- ToDo?
end

--------------------------------------------------------------------------------
-- GuildInspectorFrame
--------------------------------------------------------------------------------

function GuildInspectorFrame_UpdateGuild()
	if (IsInGuild()) then
		local guildName, guildRankName, guildRankIndex = GetGuildInfo("player");
		GuildInspectorFrameTitleText:SetText(guildName);
		SetLargeGuildTabardTextures("player", GuildInspectorFrameTabardEmblem, GuildInspectorFrameTabardBackground, GuildInspectorFrameTabardBorder);
	else
		if (GuildInspectorFrame:IsShown()) then
			HideUIPanel(GuildInspectorFrame);
		end
	end
end

function GuildInspectorFrame_SetView()
	GuildInspectorShowOfflineButton:SetChecked(GetGuildRosterShowOffline());

	local rowButtons = GuildInspectorContainer.buttons;
	local tabIndex = GuildInspectorFrame.selectedTab;
	local columnSetup;
	if (tabIndex == 1) then -- Roster
		columnSetup = GUILDINSPECTOR_COLUMNSETUPS.roster;
		GuildInspectorShowOfflineButton:Show();
		for i = 1, #rowButtons do
			rowButtons[i].icon:Show();
		end
	elseif (tabIndex == 2) then -- Log
		columnSetup = GUILDINSPECTOR_COLUMNSETUPS.log;
		GuildInspectorShowOfflineButton:Hide();
		for i = 1, #rowButtons do
			rowButtons[i].icon:Hide();
		end
	end

	-- set up columns
	local left = 0;
	for index = 1, 8 do
		local columnButton = _G["GuildInspectorColumnButton" .. index];
		local columnTypeIndex = columnSetup[index];
		if (columnTypeIndex) then
			local columnType = GUILDINSPECTOR_COLUMNTYPES[columnTypeIndex];
			columnButton:SetText(columnType.text);
			columnButton.sort = columnType.sort;
			local width = columnType.width;
			if (width == 0) then
				width = columnButton:GetTextWidth();
			end
			local columnButtonMiddle = _G["GuildInspectorColumnButton" .. index .. "Middle"];
			columnButtonMiddle:SetWidth(3 + width + 3);
			columnButton:SetWidth(5 + 3 + width + 3 + 4);
			columnButton:Show();

			-- process the button strings
			for i = 1, #rowButtons do
				local fontString = rowButtons[i]["string" .. index];
				fontString:SetPoint("LEFT", left + 5, 0);
				fontString:SetWidth(width + 2);
				fontString:SetJustifyH(columnType.alignment);
				fontString:Show();
			end

			left = left + 5 + 3 + width + 3 + 4 - 2;
		else
			columnButton:Hide();

			-- process the button strings
			for i = 1, #rowButtons do
				rowButtons[i]["string" .. index]:Hide();
			end
		end
	end
end

function GuildInspectorButton_SetStringText(buttonString, text, isOnline, class)
	buttonString:SetText(text);
	if (isOnline) then
		if (class) then
			local classColor = RAID_CLASS_COLORS[class];
			buttonString:SetTextColor(classColor.r, classColor.g, classColor.b);
		else
			buttonString:SetTextColor(HIGHLIGHT_FONT_COLOR.r, HIGHLIGHT_FONT_COLOR.g, HIGHLIGHT_FONT_COLOR.b);
		end
	else
		buttonString:SetTextColor(GRAY_FONT_COLOR.r, GRAY_FONT_COLOR.g, GRAY_FONT_COLOR.b);
	end
end

function GuildInspectorFrame_Update()
	local totalMembers, onlineMembers, onlineAndMobileMembers = GetNumGuildMembers();
	local guildName, guildRankName, guildRankIndex = GetGuildInfo("player");
	if (guildName and (totalMembers > 0)) then
		-- get current roster
		local newRoster = {};
		for index = 1, totalMembers do
			local fullName, rank, rankIndex, level, class, zone, note, officerNote, online, status, classFileName, achievementPoints, achievementRank, isMobile, canSoR, repStanding = GetGuildRosterInfo(index);
			-- ToDo: no gender or race available :-(
			newRoster[fullName] = {rank = rank, level = level, class = classFileName, note = note, oNote = officerNote};
		end

		-- find missing chars
		local oldRoster = GuildInspector_Roster[guildName];
		if (oldRoster) then
			for k, v in pairs(oldRoster) do
				if (newRoster[k] == nil) then
					GuildInspector_Missing[guildName][k] = v;
				end
			end
		end

		GuildInspector_Roster[guildName] = newRoster;
		if (GuildInspector_Missing[guildName] == nil) then GuildInspector_Missing[guildName] = {}; end
	end

	local tabIndex = GuildInspectorFrame.selectedTab;
	if (tabIndex == 1) then -- Roster
		GuildInspectorFrame_UpdateGuildRoster();
	elseif (tabIndex == 2) then -- Log
		GuildInspectorFrame_UpdateGuildEventLog();
	end
end

function GuildInspectorFrame_UpdateGuildRoster()
	local totalMembers, onlineMembers, onlineAndMobileMembers = GetNumGuildMembers();
	GuildInspectorFrameMembersCount:SetText(onlineAndMobileMembers .. " / " .. totalMembers);

	local visibleMembers = onlineAndMobileMembers;
	if (GetGuildRosterShowOffline()) then
		visibleMembers = totalMembers;
	end

	local scrollFrame = GuildInspectorContainer;
	local offset = HybridScrollFrame_GetOffset(scrollFrame);
	local buttons = scrollFrame.buttons;
	local numButtons = #buttons;
	for i = 1, numButtons do
		button = buttons[i];
		index = offset + i;
		local fullName, rank, rankIndex, level, class, zone, note, officerNote, online, status, classFileName, achievementPoints, achievementRank, isMobile, canSoR, repStanding = GetGuildRosterInfo(index);

		if (fullName and (index <= visibleMembers)) then
			button.guildIndex = index;
			local onlineOrMobile = online or isMobile;
			local displayedName = Ambiguate(fullName, "guild");
--			if (isMobile and not online) then
			if (isMobile) then
				if (status == 2) then -- Busy
					displayedName = MOBILE_BUSY_ICON .. displayedName;
				elseif (status == 1) then -- Away
					displayedName = MOBILE_AWAY_ICON .. displayedName;
				else -- Available
					displayedName = ChatFrame_GetMobileEmbeddedTexture(73/255, 177/255, 73/255) .. displayedName;
				end
			end

			GuildInspectorButton_SetStringText(button.string1, level, onlineOrMobile);
			button.icon:SetTexCoord(unpack(CLASS_ICON_TCOORDS[classFileName]));
			GuildInspectorButton_SetStringText(button.string3, displayedName, onlineOrMobile, classFileName);
			local zoneText = zone;
			if(isMobile and not online) then zoneText = REMOTE_CHAT end;
			GuildInspectorButton_SetStringText(button.string4, zoneText, onlineOrMobile);
			GuildInspectorButton_SetStringText(button.string5, rank, onlineOrMobile);
			GuildInspectorButton_SetStringText(button.string6, note, onlineOrMobile);
			GuildInspectorButton_SetStringText(button.string7, officerNote, onlineOrMobile);
--			if (onlineOrMobile) then
			if (online) then
				GuildInspectorButton_SetStringText(button.string8, GUILD_ONLINE_LABEL, onlineOrMobile);
			else
				GuildInspectorButton_SetStringText(button.string8, format(L.LOG_TIME, RecentTimeDate(GetGuildRosterLastOnline(index))), onlineOrMobile);
			end

			if (mod(index, 2) == 0) then
				button.stripe:SetTexCoord(0.36230469, 0.38183594, 0.95898438, 0.99804688);
			else
				button.stripe:SetTexCoord(0.51660156, 0.53613281, 0.88281250, 0.92187500);
			end
			button.tt = nil;

			button:Show();
		else
			button:Hide();
		end
	end
	local totalHeight = visibleMembers * (20 + 2);
	local displayedHeight = numButtons * (20 + 2);
	HybridScrollFrame_Update(scrollFrame, totalHeight, displayedHeight);
end

function GuildInspectorFrame_UpdateGuildEventLog()
	local numEvents = GetNumGuildEvents();

	local buttons = GuildInspectorContainer.buttons;
	local numButtons = #buttons;

	HybridScrollFrame_Update(GuildInspectorContainer, numEvents * (20 + 2), numButtons * (20 + 2));

	local offset = HybridScrollFrame_GetOffset(GuildInspectorContainer);
	for i = 1, numButtons do
		button = buttons[i];
		index = offset + i;

		if (index <= numEvents) then
			local type, player1, player2, rank, year, month, day, hour = GetGuildEventInfo(numEvents - (index - 1)); -- show latest events first
			if (not player1) then
				player1 = UNKNOWN;
			end
			if (not player2) then
				player2 = UNKNOWN;
			end

--[[
		GUILDEVENT_TYPE_DEMOTE = "%s demotes %s to %s";
		GUILDEVENT_TYPE_INVITE = "%s invites %s";
		GUILDEVENT_TYPE_JOIN = "%s joins the guild";
		GUILDEVENT_TYPE_PROMOTE = "%s promotes %s to %s";
		GUILDEVENT_TYPE_QUIT = "%s leaves the guild";
		GUILDEVENT_TYPE_REMOVE = "%s removes %s from the guild";
		QueryGuildEventLog
]]
			local msg
			local color = HIGHLIGHT_FONT_COLOR;
			if (type == "invite") then
				msg = format(GUILDEVENT_TYPE_INVITE, player1, player2);
				button.tt = player2;
			elseif (type == "join") then
				msg = format(GUILDEVENT_TYPE_JOIN, player1);
				color = GREEN_FONT_COLOR;
				button.tt = player1;
			elseif (type == "promote") then
				msg = format(GUILDEVENT_TYPE_PROMOTE, player1, player2, rank);
				color = YELLOW_FONT_COLOR;
				button.tt = player2;
			elseif (type == "demote") then
				msg = format(GUILDEVENT_TYPE_DEMOTE, player1, player2, rank);
				color = LIGHTYELLOW_FONT_COLOR;
				button.tt = player2;
			elseif (type == "remove") then
				msg = format(GUILDEVENT_TYPE_REMOVE, player1, player2);
				color = RED_FONT_COLOR;
				button.tt = player2;
			elseif (type == "quit") then
				msg = format(GUILDEVENT_TYPE_QUIT, player1);
				color = DULL_RED_FONT_COLOR;
				button.tt = player1;
			else
				print("[" .. AddonName .. "] " .. RED_FONT_COLOR_CODE .. "**ERROR** unknown guild event type (" .. GRAY_FONT_COLOR_CODE .. type .. RED_FONT_COLOR_CODE .. ")");
			end

			button.string1:SetText(msg);
			button.string1:SetTextColor(color.r, color.g, color.b);
			button.string2:SetText(format(L.LOG_TIME, RecentTimeDate(year, month, day, hour)), onlineOrMobile);
			button.string2:SetTextColor(GRAY_FONT_COLOR.r, GRAY_FONT_COLOR.g, GRAY_FONT_COLOR.b);

			if (mod(index, 2) == 0) then
				button.stripe:SetTexCoord(0.36230469, 0.38183594, 0.95898438, 0.99804688);
			else
				button.stripe:SetTexCoord(0.51660156, 0.53613281, 0.88281250, 0.92187500);
			end

			button:Show();
		else
			button:Hide();
		end
	end
end

function GuildInspectorFrame_ToggleSwitch()
	if (GuildInspector_Settings.toggleFunctionality) then
		GuildInspectorFrame_Toggle();
	else
		GuildInspectorFrame_Switch();
	end
end

function GuildInspectorFrame_Toggle()
	if (GuildInspectorFrame:IsShown()) then
		HideUIPanel(GuildInspectorFrame);
	else
		GuildInspectorFrame_SetView();
		GuildInspectorFrame_Update();
		ShowUIPanel(GuildInspectorFrame);
	end
end

function GuildInspectorFrame_Switch()
	local tabIndex = GuildInspectorFrame.selectedTab;
	if (not GuildInspectorFrame:IsShown()) then
		PanelTemplates_SetTab(GuildInspectorFrame, GuildInspectorFrameTab1:GetID());
		GuildInspectorFrame_SetView();
		GuildInspectorFrame_Update();
		ShowUIPanel(GuildInspectorFrame);
	elseif (tabIndex == 1) then -- Roster
		PanelTemplates_SetTab(GuildInspectorFrame, GuildInspectorFrameTab2:GetID());
		GuildInspectorFrame_SetView();
		GuildInspectorFrame_Update();
	elseif (tabIndex == 2) then -- Log
		HideUIPanel(GuildInspectorFrame);
	end
end

--------------------------------------------------------------------------------
-- register slash command
--------------------------------------------------------------------------------

SLASH_GUILDINSPECTOR1 = "/GuildInspector";
SLASH_GUILDINSPECTOR2 = "/gi";

function SlashCmdList.GUILDINSPECTOR(msg, editbox)
	local tokens = {};
	for token in msg:gmatch("%S+") do table.insert(tokens, token) end

	if ((#tokens == 0) or (strlower(tokens[1]) == "config") or (strlower(tokens[1]) == "options") or (strlower(tokens[1]) == "settings")) then
		InterfaceOptionsFrame_OpenToCategory("Guild Inspector");
		InterfaceOptionsFrame_OpenToCategory("Guild Inspector"); -- call twice, because of a bug in Blizzards code
	elseif (strlower(tokens[1]) == "switch") then
		GuildInspectorFrame_Switch();
	elseif (strlower(tokens[1]) == "toggle") then
		GuildInspectorFrame_Toggle();
	else
		print("Syntax: " .. YELLOW_FONT_COLOR_CODE .. "/GuildInspector|r || " .. YELLOW_FONT_COLOR_CODE .. "/gi|r [cmd]");
		print("help - " .. YELLOW_FONT_COLOR_CODE .. "show this help|r");
		print("config - " .. YELLOW_FONT_COLOR_CODE .. "open the configuration dialog|r [Default]");
		print("switch - " .. YELLOW_FONT_COLOR_CODE .. "switch tab");
		print("toggle - " .. YELLOW_FONT_COLOR_CODE .. "toggle window");
	end
end